==> aTunes_1.9.0.tar.gz: aTunes/src/net/sourceforge/atunes/gui/popup/FadingPopup.java <==
/*
 * aTunes 1.9.0
 * Copyright (C) 2006-2008 Alex Aranda, Sylvain Gaudard, Thomas Beckers and contributors
 *
 * See http://www.atunes.org/wiki/index.php?title=Contributing for information about contributors
 *
 * http://www.atunes.org
 * http://sourceforge.net/projects/atunes
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

package net.sourceforge.atunes.gui.popup;

import java.awt.BorderLayout;
import java.awt.Component;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JComponent;
import javax.swing.JWindow;
import javax.swing.Popup;
import javax.swing.Timer;

import net.sourceforge.atunes.gui.GuiUtils;

import org.jvnet.lafwidget.utils.ShadowPopupBorder;

/**
 * Based on a fading popup with shadow border by Kirill Grouchnikov.
 */
class FadingPopup extends Popup {

	/** The popup window. */
	JWindow popupWindow;

	/** The curr opacity. */
	int currOpacity;

	/** The fade in timer. */
	Timer fadeInTimer;

	/** The fade out timer. */
	Timer fadeOutTimer;

	/**
	 * Instantiates a new fading popup.
	 * 
	 * @param owner
	 *            the owner
	 * @param contents
	 *            the contents
	 * @param ownerX
	 *            the owner x
	 * @param ownerY
	 *            the owner y
	 */
	FadingPopup(Component owner, Component contents, int ownerX, int ownerY) {
		// create a new heavyweighht window
		this.popupWindow = new JWindow();
		// determine the popup location
		popupWindow.setLocation(ownerX, ownerY);
		// add the contents to the popup
		popupWindow.getContentPane().add(contents, BorderLayout.CENTER);
		contents.invalidate();
		JComponent parent = (JComponent) contents.getParent();
		// set the shadow border
		parent.setBorder(ShadowPopupBorder.getInstance());

	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see javax.swing.Popup#show()
	 */
	@Override
	public void show() {
		// mark the popup with 0% opacity
		this.currOpacity = 0;
		GuiUtils.setWindowOpacity(popupWindow, 0.0f);

		this.popupWindow.setVisible(true);
		this.popupWindow.pack();

		// mark the window as non-opaque, so that the
		// shadow border pixels take on the per-pixel
		// translucency
		GuiUtils.setWindowOpaque(this.popupWindow, false);

		// start fading in
		this.fadeInTimer = new Timer(50, new ActionListener() {
			public void actionPerformed(@SuppressWarnings("unused")
			ActionEvent e) {
				currOpacity += 20;
				if (currOpacity <= 100) {
					GuiUtils.setWindowOpacity(popupWindow, currOpacity / 100.0f);
					// workaround bug 6670649 - should call
					// popupWindow.repaint() but that will not repaint the
					// panel
					popupWindow.getContentPane().repaint();
				} else {
					currOpacity = 100;
					fadeInTimer.stop();
				}
			}
		});
		this.fadeInTimer.setRepeats(true);
		this.fadeInTimer.start();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see javax.swing.Popup#hide()
	 */
	@Override
	public void hide() {
		// cancel fade-in if it's running.
		if (this.fadeInTimer.isRunning())
			this.fadeInTimer.stop();

		// start fading out
		this.fadeOutTimer = new Timer(50, new ActionListener() {
			public void actionPerformed(@SuppressWarnings("unused")
			ActionEvent e) {
				currOpacity -= 10;
				if (currOpacity >= 0) {
					GuiUtils.setWindowOpacity(popupWindow, currOpacity / 100.0f);
					// workaround bug 6670649 - should call
					// popupWindow.repaint() but that will not repaint the
					// panel
					popupWindow.getContentPane().repaint();
				} else {
					fadeOutTimer.stop();
					popupWindow.setVisible(false);
					popupWindow.removeAll();
					popupWindow.dispose();
					currOpacity = 0;
				}
			}
		});
		this.fadeOutTimer.setRepeats(true);
		this.fadeOutTimer.start();
	}
}

==> aTunes_1.10.1.tar.gz: aTunes/src/net/sourceforge/atunes/gui/popup/FadingPopup.java <==
/*
 * aTunes 1.10.1
 * Copyright (C) 2006-2008 Alex Aranda, Sylvain Gaudard, Thomas Beckers and contributors
 *
 * See http://www.atunes.org/wiki/index.php?title=Contributing for information about contributors
 *
 * http://www.atunes.org
 * http://sourceforge.net/projects/atunes
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

package net.sourceforge.atunes.gui.popup;

import java.awt.BorderLayout;
import java.awt.Component;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JComponent;
import javax.swing.JWindow;
import javax.swing.Popup;
import javax.swing.Timer;

import net.sourceforge.atunes.gui.GuiUtils;

import org.jvnet.lafwidget.utils.ShadowPopupBorder;

/**
 * Based on a fading popup with shadow border by Kirill Grouchnikov.
 */
class FadingPopup extends Popup {

	/** The popup window. */
	JWindow popupWindow;

	/** The curr opacity. */
	int currOpacity;

	/** The fade in timer. */
	Timer fadeInTimer;

	/** The fade out timer. */
	Timer fadeOutTimer;

	/**
	 * Instantiates a new fading popup.
	 * 
	 * @param owner
	 *            the owner
	 * @param contents
	 *            the contents
	 * @param ownerX
	 *            the owner x
	 * @param ownerY
	 *            the owner y
	 */
	FadingPopup(Component owner, Component contents, int ownerX, int ownerY) {
		// create a new heavyweighht window
		this.popupWindow = new JWindow();
		// determine the popup location
		popupWindow.setLocation(ownerX, ownerY);
		// add the contents to the popup
		popupWindow.getContentPane().add(contents, BorderLayout.CENTER);
		contents.invalidate();
		JComponent parent = (JComponent) contents.getParent();
		// set the shadow border
		parent.setBorder(ShadowPopupBorder.getInstance());

	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see javax.swing.Popup#show()
	 */
	@Override
	public void show() {
		// mark the popup with 0% opacity
		this.currOpacity = 0;
		GuiUtils.setWindowOpacity(popupWindow, 0.0f);

		this.popupWindow.setVisible(true);
		this.popupWindow.pack();

		// mark the window as non-opaque, so that the
		// shadow border pixels take on the per-pixel
		// translucency
		GuiUtils.setWindowOpaque(this.popupWindow, false);

		// start fading in
		this.fadeInTimer = new Timer(50, new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				currOpacity += 20;
				if (currOpacity <= 100) {
					GuiUtils.setWindowOpacity(popupWindow, currOpacity / 100.0f);
					// workaround bug 6670649 - should call
					// popupWindow.repaint() but that will not repaint the
					// panel
					popupWindow.getContentPane().repaint();
				} else {
					currOpacity = 100;
					fadeInTimer.stop();
				}
			}
		});
		this.fadeInTimer.setRepeats(true);
		this.fadeInTimer.start();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see javax.swing.Popup#hide()
	 */
	@Override
	public void hide() {
		// cancel fade-in if it's running.
		if (this.fadeInTimer.isRunning()) {
			this.fadeInTimer.stop();
		}

		// start fading out
		this.fadeOutTimer = new Timer(50, new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				currOpacity -= 10;
				if (currOpacity >= 0) {
					GuiUtils.setWindowOpacity(popupWindow, currOpacity / 100.0f);
					// workaround bug 6670649 - should call
					// popupWindow.repaint() but that will not repaint the
					// panel
					popupWindow.getContentPane().repaint();
				} else {
					fadeOutTimer.stop();
					popupWindow.setVisible(false);
					popupWindow.removeAll();
					popupWindow.dispose();
					currOpacity = 0;
				}
			}
		});
		this.fadeOutTimer.setRepeats(true);
		this.fadeOutTimer.start();
	}
}
